@@ -504,11 +504,16 @@ connectRedShift <- function(connectionDetails) {
     }
     connectionString <- paste("jdbc:redshift://", host, ":", port, "/", database, sep = "")
     if (!is.null(connectionDetails$extraSettings)) {
-      connectionString <- paste(connectionString, connectionDetails$extraSettings, sep = "?")
+      connectionString <- paste(connectionString, connectionDetails$extraSettings, sep = ";")
     }
   } else {
     connectionString <- connectionDetails$connectionString()
   }
+  # Default fetchRingBufferSize is 1GB, which is a bit extreme and causing Java out of heap
+  # error, so set to something more reasonable if the users didn't already do that:
+  if (!grepl("fetchRingBufferSize", connectionString)) {
+    connectionString <- paste(connectionString, "fetchRingBufferSize=100M", sep = ";")
+  }
   if (is.null(connectionDetails$user())) {
     connection <- connectUsingJdbcDriver(driver, connectionString, dbms = connectionDetails$dbms)
   } else {
@@ -594,7 +599,7 @@ connectHive <- function(connectionDetails) {
   driver <- getJbcDriverSingleton("org.apache.hive.jdbc.HiveDriver", jarPath)
 
   if (is.null(connectionDetails$connectionString()) || connectionDetails$connectionString() == "") {
-    connectionString <- paste0("jdbc:hive2://", connectionDetails$server, ":", connectionDetails$port, "/")
+    connectionString <- paste0("jdbc:hive2://", connectionDetails$server(), ":", connectionDetails$port(), "/")
     if (!is.null(connectionDetails$extraSettings)) {
       connectionString <- paste(connectionString, connectionDetails$extraSettings, sep = ";")
     }
